=== modified file 'tests/test_upload_jenkins_job.py'
--- tests/test_upload_jenkins_job.py	2016-03-14 17:07:02 +0000
+++ tests/test_upload_jenkins_job.py	2016-05-03 00:01:23 +0000
@@ -384,6 +384,25 @@
         self.assertEqual(s3_mock.store.mock_calls, calls)
         jenkins_mock.artifacts.assert_called_once_with()
 
+    def test_upload_artifacts_file_ext(self):
+
+        def artifacts_fake():
+            for filename, i in zip(['foo.log', 'bar.svg', 'result.json'],
+                                   xrange(1, 4)):
+                yield filename, "artifact data {}".format(i)
+        _, _, s3_mock, jenkins_mock = self._make_upload_artifacts(BUILD_NUM)
+        jenkins_mock.artifacts.return_value = artifacts_fake()
+        h = S3Uploader(s3_mock, jenkins_mock,
+                       artifact_file_ext=['.json', '.svg'])
+        h.upload_artifacts()
+        calls = [
+            call('1277-log-bar.svg', 'artifact data 2',
+                 headers={'Content-Type': 'image/svg+xml'}),
+            call('1277-log-result.json', 'artifact data 3',
+                 headers={'Content-Type': 'application/json'})]
+        self.assertEqual(s3_mock.store.mock_calls, calls)
+        jenkins_mock.artifacts.assert_called_once_with()
+
     def _make_upload_artifacts(self, file_prefix):
         filename = '{}-log-filename'.format(file_prefix)
         headers = {"Content-Type": "application/octet-stream"}
@@ -573,9 +592,17 @@
     def test_get_args_default(self):
         args = get_args([JOB_NAME, str(BUILD_NUM), BUCKET, DIRECTORY])
         self.assertEqual(args, Namespace(
-            all=False, build_number=1277, jenkins_job=JOB_NAME, latest=False,
-            password=None, s3_bucket=BUCKET, s3_directory=DIRECTORY,
-            unique_id=None, user=None, no_prefixes=False))
+            all=False, artifact_file_ext=None, build_number=1277,
+            jenkins_job=JOB_NAME, latest=False, password=None,
+            s3_bucket=BUCKET, s3_directory=DIRECTORY, unique_id=None,
+            user=None, no_prefixes=False))
+
+    def test_get_args_artifact_file_ext(self):
+        args = get_args([JOB_NAME, str(BUILD_NUM), BUCKET, DIRECTORY,
+                         '--artifact-file-ext', '.svg', '.json',
+                         '--unique-id', '1234'])
+        self.assertEqual(args.artifact_file_ext, ['.svg', '.json'])
+        self.assertEqual(args.unique_id, '1234')
 
     def test_get_s3_access(self):
         path = '/u/home'

=== modified file 'upload_jenkins_job.py'
--- upload_jenkins_job.py	2016-03-14 17:07:02 +0000
+++ upload_jenkins_job.py	2016-05-03 00:01:23 +0000
@@ -175,15 +175,18 @@
     Uploads the result of a Jenkins job to S3.
     """
 
-    def __init__(self, s3, jenkins_build, unique_id=None, no_prefixes=False):
+    def __init__(self, s3, jenkins_build, unique_id=None, no_prefixes=False,
+                 artifact_file_ext=None):
         self.s3 = s3
         self.jenkins_build = jenkins_build
         self.unique_id = unique_id
         self.no_prefixes = no_prefixes
+        self.artifact_file_ext = artifact_file_ext
 
     @classmethod
     def factory(cls, credentials, jenkins_job, build_number, bucket,
-                directory, unique_id=None, no_prefixes=False):
+                directory, unique_id=None, no_prefixes=False,
+                artifact_file_ext=None):
         """
         Creates S3Uploader.
         :param credentials: Jenkins credential
@@ -191,6 +194,8 @@
         :param build_number: Jenkins build number
         :param bucket: S3 bucket name
         :param directory: S3 directory name
+        :param artifact_file_ext: List of artifact file extentions. If set,
+        only artifact with these ejections will be uploaded.
         :rtype: S3Uploader
         """
         s3 = S3.factory(bucket, directory)
@@ -199,7 +204,8 @@
             credentials=credentials, job_name=jenkins_job,
             build_number=build_number)
         return cls(s3, jenkins_build,
-                   unique_id=unique_id, no_prefixes=no_prefixes)
+                   unique_id=unique_id, no_prefixes=no_prefixes,
+                   artifact_file_ext=artifact_file_ext)
 
     def upload(self):
         """Uploads Jenkins job results, console logs and artifacts to S3.
@@ -280,6 +286,9 @@
 
     def upload_artifacts(self):
         for filename, content in self.jenkins_build.artifacts():
+            if self.artifact_file_ext:
+                if os.path.splitext(filename)[1] not in self.artifact_file_ext:
+                    continue
             filename = self._create_filename(filename)
             headers = self.make_headers(filename)
             self.s3.store(filename, content, headers=headers)
@@ -329,6 +338,10 @@
     parser.add_argument(
         '--no-prefixes', action='store_true', default=False,
         help='Do not add prefixes to file names; the s3_directory is unique.')
+    parser.add_argument(
+        '--artifact-file-ext', nargs='+',
+        help='Artifacts include file extentions. If set, only files with '
+             'these extentions will be uploaded.')
     add_credential_args(parser)
     args = parser.parse_args(argv)
     args.all = False
@@ -350,7 +363,7 @@
     uploader = S3Uploader.factory(
         cred, args.jenkins_job, args.build_number, args.s3_bucket,
         args.s3_directory, unique_id=args.unique_id,
-        no_prefixes=args.no_prefixes)
+        no_prefixes=args.no_prefixes, artifact_file_ext=args.artifact_file_ext)
     if args.build_number:
         print('Uploading build number {:d}.'.format(args.build_number))
         uploader.upload()

